#!/bin/bash

#################################################################
##                                                             ##
##  Serpro Signer Bootstrap for UN*X                           ##
##                                                             ##
#################################################################

### $Id$ ###

DIRNAME=`dirname $0`

# OS specific support (must be 'true' or 'false').
cygwin=false;
darwin=false;
case "`uname`" in
    CYGWIN*)
        cygwin=true
        ;;
    Darwin*)
        darwin=true
        ;;
esac


# Setup SERPRO_SIGNER_HOME
if [ "x$SERPRO_SIGNER_HOME" = "x" ]; then
    # get the full path (without any relative bits)
    SERPRO_SIGNER_HOME=`cd $DIRNAME; pwd`
fi

export SERPRO_SIGNER_HOME

UNAME=$(uname -m)
echo $UNAME

if  [[ $UNAME == *'x86_64'* ]] ; then
  SIGNER_JAVA_HOME=`cd $SERPRO_SIGNER_HOME/jre_64/; pwd`
 else
   echo "Architetura não suportada" > $SERPRO_SIGNER_HOME/SerproSignerError.txt
fi

export SIGNER_JAVA_HOME
echo $SIGNER_JAVA_HOME > /tmp/SerproSignerInfo2.txt


if [ -f "$SIGNER_JAVA_HOME/bin/java" ]
then
  JAVA=$SIGNER_JAVA_HOME/bin/java
else
   echo "Não encontrou java" > /tmp/SerproSignerError.txt
    exit
fi


JAVA_OPTS="-Xms256m -Xmx4096m -XX:MinHeapFreeRatio=20 -XX:MaxHeapFreeRatio=40 -Djava.net.preferIPv4Stack=true -Djava.net.preferIPv6Addresses=false -Djava.net.useSystemProxies=true -Dfile.encoding=UTF-8 -Dhttps.protocols=TLSv1.1,TLSv1.2 -Duser.timezone=GMT-3 -Djava.io.tmpdir=/tmp -Djdk.tls.client.protocols=TLSv1.2,TLSv1.1" 

# -Djava.compiler=NONE -Xnoagent -Xdebug -Xrunjdwp:transport=dt_socket,address=2502,server=y,suspend=n

if $darwin
then
    JAVA_OPTS="$JAVA_OPTS -Dswing.crossplatformlaf=apple.laf.AquaLookAndFeel -Dapple.eawt.quitStrategy=CLOSE_ALL_WINDOWS"
fi

if [ $SERPRO_SIGNER_HOME != "" ] 
then
    JAVA_OPTS="$JAVA_OPTS -Djava.library.path=$SERPRO_SIGNER_HOME"
fi

export JAVA_OPTS

# For Cygwin, switch paths to Windows format before running java
if [ $cygwin = "true" ] 
then
    SERPRO_SIGNER_HOME=`cygpath --path --dos "$SERPRO_SIGNER_HOME"`
fi

cd $DIRNAME

if [ -d /opt/firefox ]; then
  export LD_LIBRARY_PATH=/opt/firefox/
 echo "/opt/firefox" 
elif [ -d /usr/lib/firefox ];    then
       export LD_LIBRARY_PATH=/usr/lib/firefox/
 	echo "/usr/lib/firefox/"
     elif [ -d /usr/lib64/firefox ];  then 
         export LD_LIBRARY_PATH=/usr/lib64/firefox/
          echo "/usr/lib64/firefox"     
fi

xhost +local:all

ulimit -c unlimited

$JAVA $JAVA_OPTS -cp $SERPRO_SIGNER_HOME/lib/serpro-signer-4.0.2.jar:$SERPRO_SIGNER_HOME/lib/plugins/* org.demoiselle.signer.serpro.desktop.Main
exit 0
